pub struct EnvBuilder { /* private fields */ }Expand description
Environment factory in order to configure the properties.
Implementations
Sourceimpl EnvBuilder
impl EnvBuilder
Sourcepub fn new() -> EnvBuilder
pub fn new() -> EnvBuilder
Initialize a new EnvBuilder.
Sourcepub fn cq_count(self, count: usize) -> EnvBuilder
pub fn cq_count(self, count: usize) -> EnvBuilder
Set the number of completion queues and polling threads. Each thread polls one completion queue.
Panics
This method will panic if count is 0.
Sourcepub fn name_prefix<S>(self, prefix: S) -> EnvBuilder
pub fn name_prefix<S>(self, prefix: S) -> EnvBuilder
Set the thread name prefix of each polling thread.
Sourcepub fn build(self) -> Environment
pub fn build(self) -> Environment
Finalize the EnvBuilder, build the Environment and initialize the gRPC library.